Plotting
========

* Intuitive plotting routines with ``matplotlib`` similar syntax (see :ref:`plotting_ref`)
* PyQt plotting windows and embeddable renderers (see :ref:`qt_ref`)
* Plotting tools built for interactivity (see :ref:`widgets`)

.. toctree::
   :maxdepth: 2

   plotting
   qt_plotting
   itk_plotting
   widgets
